@@ -7,7 +7,7 @@ RDF::Query::Algebra::Sequence - Algebra class for a sequence of algebra operatio
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Sequence version 2.902.
+This document describes RDF::Query::Algebra::Sequence version 2.903.
 
 =cut
 
@@ -30,7 +30,7 @@ use RDF::Trine::Iterator qw(smap swatch);
 our ($VERSION);
 my %AS_SPARQL;
 BEGIN {
-	$VERSION	= '2.902';
+	$VERSION	= '2.903';
 }
 
 ######################################################################
@@ -157,17 +157,17 @@ sub referenced_variables {
 	return RDF::Query::_uniq(map { $_->referenced_variables } $self->patterns);
 }
 
-=item C<< binding_variables >>
+=item C<< potentially_bound >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub binding_variables {
+sub potentially_bound {
 	my $self	= shift;
 	my @patterns	= $self->patterns;
-	return $patterns[ $#patterns ]->binding_variables;
+	return $patterns[ $#patterns ]->potentially_bound;
 }
 
 =item C<< definite_variables >>
@@ -179,7 +179,7 @@ Returns a list of the variable names that will be bound after evaluating this al
 sub definite_variables {
 	my $self	= shift;
 	my @patterns	= $self->patterns;
-	return $patterns[ $#patterns ]->binding_variables;
+	return $patterns[ $#patterns ]->potentially_bound;
 }
 
 =item C<< clone >>
