@@ -7,7 +7,7 @@ RDF::Query::Plan::Clear - Executable query plan for CLEAR operations.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Clear version 2.902.
+This document describes RDF::Query::Plan::Clear version 2.903.
 
 =head1 METHODS
 
@@ -33,7 +33,7 @@ use RDF::Query::VariableBindings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.902';
+	$VERSION	= '2.903';
 }
 
 ######################################################################
@@ -71,7 +71,17 @@ sub execute ($) {
 # 	warn "clearing graph " . $graph->as_string;
 	my $ok	= 0;
 	try {
-		$context->model->remove_statements( undef, undef, undef, $graph );
+		my $uri	= $graph->uri_value;
+		if ($uri eq 'tag:gwilliams@cpan.org,2010-01-01:RT:ALL') {
+			$context->model->remove_statements( undef, undef, undef, undef );
+		} elsif ($uri eq 'tag:gwilliams@cpan.org,2010-01-01:RT:NAMED') {
+			my $citer	= $context->model->get_contexts;
+			while (my $graph = $citer->next) {
+				$context->model->remove_statements( undef, undef, undef, $graph );
+			}
+		} else {
+			$context->model->remove_statements( undef, undef, undef, $graph );
+		}
 		$ok		= 1;
 	} catch RDF::Trine::Error with {};
 	$self->[0]{ok}	= $ok;
@@ -159,7 +169,12 @@ identifiers.
 
 sub plan_prototype {
 	my $self	= shift;
-	return qw(N);
+	my $g	= $self->namedgraph;
+	if ($g->isa('RDF::Query::Node::Resource') and $g->uri_value =~ m'^tag:gwilliams@cpan[.]org,2010-01-01:RT:(NAMED|ALL)$') {
+		return qw(w);
+	} else {
+		return qw(N);
+	}
 }
 
 =item C<< plan_node_data >>
@@ -171,8 +186,12 @@ the signature returned by C<< plan_prototype >>.
 
 sub plan_node_data {
 	my $self	= shift;
-	Carp::cluck $self;
-	return ($self->namedgraph);
+	my $g	= $self->namedgraph;
+	if ($g->isa('RDF::Query::Node::Resource') and $g->uri_value =~ m'^tag:gwilliams@cpan[.]org,2010-01-01:RT:(NAMED|ALL)$') {
+		return $1;
+	} else {
+		return ($self->namedgraph);
+	}
 }
 
 =item C<< graph ( $g ) >>
