@@ -7,7 +7,7 @@ RDF::Query::Plan::SubSelect - Executable query plan for sub-select queries.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::SubSelect version 2.902.
+This document describes RDF::Query::Plan::SubSelect version 2.903.
 
 =head1 METHODS
 
@@ -34,7 +34,7 @@ use RDF::Query::VariableBindings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION		= '2.902';
+	$VERSION		= '2.903';
 }
 
 ######################################################################
@@ -49,8 +49,12 @@ representing a SELECT query.
 sub new {
 	my $class	= shift;
 	my $query	= shift;
-	my $keys	= shift || {};
-	my $self	= $class->SUPER::new( $query );
+	my $plan	= shift;
+	unless (blessed($plan) and $plan->isa('RDF::Query::Plan')) {
+		Carp::confess;
+	}
+	my $keys	= {};
+	my $self	= $class->SUPER::new( $query, $plan );
 	$self->[0]{referenced_variables}	= [ $query->variables ];
 	$self->[0]{logging_keys}	= $keys;
 	return $self;
@@ -66,9 +70,11 @@ sub execute ($) {
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "SUBSELECT plan can't be executed while already open";
 	}
-	my $l		= Log::Log4perl->get_logger("rdf.query.plan.subselect");
-	my $query	= $self->query;
-	my $iter	= $query->execute( $context->model );
+	my $l				= Log::Log4perl->get_logger("rdf.query.plan.subselect");
+	$l->trace("executing subselect");
+	my $plan			= $self->plan;
+	$l->trace("subselect plan: " . $plan->sse);
+	my $iter			= $plan->execute( $context );
 	if ($iter) {
 		$self->[0]{iter}	= $iter;
 		$self->[0]{'open'}	= 1;
@@ -90,11 +96,13 @@ sub next {
 	unless ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "next() cannot be called on an un-open SERVICE";
 	}
+	my $l		= Log::Log4perl->get_logger("rdf.query.plan.subselect");
 	return undef unless ($self->[0]{'open'});
 	my $iter	= $self->[0]{iter};
 	my $result	= $iter->next;
 	
 	return undef unless $result;
+	$l->trace("- got subselect result $result");
 	$self->[0]{'count'}++;
 	my $row	= RDF::Query::VariableBindings->new( $result );
 	return $row;
@@ -109,6 +117,8 @@ sub close {
 	unless ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "close() cannot be called on an un-open SERVICE";
 	}
+	my $plan			= $self->plan;
+	$plan->close();
 	delete $self->[0]{iter};
 	delete $self->[0]{args};
 	delete $self->[0]{count};
@@ -126,6 +136,17 @@ sub query {
 	return $self->[1];
 }
 
+=item C<< plan >>
+
+Returns the sub-select query plan object.
+
+=cut
+
+sub plan {
+	my $self	= shift;
+	return $self->[2];
+}
+
 =item C<< distinct >>
 
 Returns true if the pattern is guaranteed to return distinct results.
@@ -172,7 +193,7 @@ identifiers.
 
 sub plan_prototype {
 	my $self	= shift;
-	return qw(q);
+	return qw(P);
 }
 
 =item C<< plan_node_data >>
@@ -184,7 +205,7 @@ the signature returned by C<< plan_prototype >>.
 
 sub plan_node_data {
 	my $self	= shift;
-	return ($self->query);
+	return ($self->plan);
 }
 
 =item C<< graph ( $g ) >>
