@@ -7,7 +7,7 @@ RDF::Query::Plan::Update - Executable query plan for DELETE/INSERT operations.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Update version 2.902.
+This document describes RDF::Query::Plan::Update version 2.903.
 
 =head1 METHODS
 
@@ -33,7 +33,7 @@ use RDF::Query::VariableBindings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.902';
+	$VERSION	= '2.903';
 }
 
 ######################################################################
@@ -82,7 +82,7 @@ sub execute ($) {
 		}
 		
 		my @operations	= (
-			[$delete_template, 'remove_statement'],
+			[$delete_template, 'remove_statements'],
 			[$insert_template, 'add_statement'],
 		);
 		
@@ -112,20 +112,30 @@ sub execute ($) {
 							$nodes[$i]	= $self->[0]{blank_map}{ $id };
 						}
 					}
-					my $ok	= 1;
-					foreach (@nodes) {
-						if (not blessed($_)) {
-							$ok	= 0;
-						} elsif ($_->isa('RDF::Trine::Node::Variable')) {
-							$ok	= 0;
+# 					my $ok	= 1;
+					foreach my $i (0 .. 3) {
+						my $n	= $nodes[ $i ];
+						if (not blessed($n)) {
+							if ($i == 3) {
+								$nodes[ $i ]	= RDF::Trine::Node::Nil->new();
+							} else {
+								$nodes[ $i ]	= RDF::Query::Node::Variable->new();
+							}
+# 							$ok	= 0;
+# 						} elsif ($n->isa('RDF::Trine::Node::Variable')) {
+# 							$ok	= 0;
 						}
 					}
-					next unless ($ok);
+# 					next unless ($ok);
 					my $st	= (scalar(@nodes) == 4)
 							? RDF::Trine::Statement::Quad->new( @nodes )
 							: RDF::Trine::Statement->new( @nodes );
 					$l->trace( "$method: " . $st->as_string );
-					$context->model->$method( $st );
+					if ($method eq 'remove_statements') {
+						$context->model->$method( $st->nodes );
+					} else {
+						$context->model->$method( $st );
+					}
 				}
 			}
 		}
@@ -274,7 +284,7 @@ sub graph {
 	my $g		= shift;
 	my $label	= $self->graph_labels;
 	my $url		= $self->url->uri_value;
-	die;
+	throw RDF::Query::Error::ExecutionError -text => "RDF::Query::Plan::Update->graph not implemented.";
 # 	$g->add_node( "$self", label => "delete" . $self->graph_labels );
 # 	$g->add_node( "${self}$url", label => $url );
 # 	$g->add_edge( "$self" => "${self}$url", label => 'url' );
