@@ -7,7 +7,7 @@ RDF::Query::Util - Miscellaneous utility functions to support work with RDF::Que
 
 =head1 VERSION
 
-This document describes RDF::Query::Util version 2.902.
+This document describes RDF::Query::Util version 2.903.
 
 =head1 SYNOPSIS
 
@@ -33,12 +33,14 @@ use Carp qw(carp croak confess);
 use URI::file;
 use RDF::Query;
 use LWP::Simple;
+use File::Spec;
+use JSON;
 
 ######################################################################
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.902';
+	$VERSION	= '2.903';
 }
 
 ######################################################################
@@ -70,6 +72,15 @@ PREFIX wn: <http://xmlns.com/wordnet/1.6/>
 PREFIX wot: <http://xmlns.com/wot/0.1/>
 END
 
+{
+	my $file	= File::Spec->catfile($ENV{HOME}, '.prefix-cmd', 'prefixes.json');
+	if (-r $file) {
+		my $json		= do { local($/) = undef; open( my $fh, '<', $file ) or next; <$fh> };
+		my $prefixes	= from_json($json);
+		$PREFIXES	= join("\n", map { "PREFIX $_: <" . $prefixes->{$_} . ">" } (keys %$prefixes));
+	}
+}
+
 =item C<< cli_make_query_and_model >>
 
 Returns a query object, model, and args HASHref based on the arguments in @ARGV.
@@ -216,7 +227,7 @@ The allowable arguments are listed below.
 =cut
 
 sub cli_parse_args {
-	my %args;
+	my %args	= @_;
 	$args{ class }	= 'RDF::Query';
 	my @service_descriptions;
 	
@@ -280,7 +291,17 @@ sub cli_parse_args {
 		} elsif ($opt eq '-m') {
 			$args{ model }	= shift(@ARGV);
 		} elsif ($opt eq '-w') {
-			$args{ update }	= 1;
+			if (exists($args{update}) and not($args{update})) {
+				warn "Model requested to be both read-only and read-write.\n";
+			} else {
+				$args{ update }	= 1;
+			}
+		} elsif ($opt eq '-r') {
+			if (exists($args{update}) and $args{update}) {
+				warn "Model requested to be both read-only and read-write.\n";
+			} else {
+				$args{ update }	= 0;
+			}
 		} elsif ($opt eq '--') {
 			last;
 		}
